@@ -12,13 +12,13 @@ class Answer(object):
     content = Column(Text)
 
 if __name__ == '__main__':
-    database = Database('sqlite://')
-    database.create_tables()
+    db = Database('sqlite://')
+    db.create_tables()
     
     question = Question(title = 'What is Quick ORM ?', content = 'What is Quick ORM ?')
     answer = Answer(question = question, content = 'Quick ORM is a python ORM which enables you to get started in less than a minute!')
-    database.session.add_then_commit(answer)
+    db.session.add_then_commit(answer)
     
-    question = database.session.query(Question).get(1)
+    question = db.session.query(Question).get(1)
     print 'The question is:', question.title
     print 'The answer is:', question.answers.first().content
