@@ -6,11 +6,11 @@ class User(object):
     name = Column(String(30))
 
 if __name__ == '__main__':
-    database = Database('sqlite://')
-    database.create_tables()
+    db = Database('sqlite://')
+    db.create_tables()
     
     user = User(name = 'Hello World')
-    database.session.add_then_commit(user)
+    db.session.add_then_commit(user)
     
-    user = database.session.query(User).get(1)
+    user = db.session.query(User).get(1)
     print 'My name is', user.name
