@@ -1,5 +1,5 @@
 from quick_orm.core import Database
-from sqlalchemy import Column, String, Text
+from sqlalchemy import Column, String
 
 class User(object):
     __metaclass__ = Database.DefaultMeta
@@ -11,15 +11,13 @@ class Role(object):
     name = Column(String(30))
 
 if __name__ == '__main__':
-    database = Database('sqlite://')
-    database.create_tables()
+    db = Database('sqlite://')
+    db.create_tables()
     
     user1 = User(name = 'Tyler Long')
-    database.session.add(user1)
     user2 = User(name = 'Peter Lau')
-    database.session.add(user1)
     role = Role(name = 'Administrator', users = [user1, user2])
-    database.session.add_then_commit(role)
+    db.session.add_then_commit(role)
 
-    admin_role = database.session.query(Role).filter_by(name = 'Administrator').one()
+    admin_role = db.session.query(Role).filter_by(name = 'Administrator').one()
     print ', '.join([user.name for user in admin_role.users]), 'are admintrators'
